/* This file is autogenerated by mkpfunc */
typedef char*(*PFUNC)(PSTATE*, char *beg, char *end, U32 utf8, SV* self);
static PFUNC parsefunc[] = {
    parse_null,     /*   0 */
    parse_null,     /*   1 */
    parse_null,     /*   2 */
    parse_null,     /*   3 */
    parse_null,     /*   4 */
    parse_null,     /*   5 */
    parse_null,     /*   6 */
    parse_null,     /*   7 */
    parse_null,     /*   8 */
    parse_null,     /*   9 */
    parse_null,     /*  10 */
    parse_null,     /*  11 */
    parse_null,     /*  12 */
    parse_null,     /*  13 */
    parse_null,     /*  14 */
    parse_null,     /*  15 */
    parse_null,     /*  16 */
    parse_null,     /*  17 */
    parse_null,     /*  18 */
    parse_null,     /*  19 */
    parse_null,     /*  20 */
    parse_null,     /*  21 */
    parse_null,     /*  22 */
    parse_null,     /*  23 */
    parse_null,     /*  24 */
    parse_null,     /*  25 */
    parse_null,     /*  26 */
    parse_null,     /*  27 */
    parse_null,     /*  28 */
    parse_null,     /*  29 */
    parse_null,     /*  30 */
    parse_null,     /*  31 */
    parse_null,     /*  32 */
    parse_decl,     /*  33 */
    parse_null,     /*  34 */
    parse_null,     /*  35 */
    parse_null,     /*  36 */
    parse_null,     /*  37 */
    parse_null,     /*  38 */
    parse_null,     /*  39 */
    parse_null,     /*  40 */
    parse_null,     /*  41 */
    parse_null,     /*  42 */
    parse_null,     /*  43 */
    parse_null,     /*  44 */
    parse_null,     /*  45 */
    parse_null,     /*  46 */
    parse_end,      /*  47 */
    parse_null,     /*  48 */
    parse_null,     /*  49 */
    parse_null,     /*  50 */
    parse_null,     /*  51 */
    parse_null,     /*  52 */
    parse_null,     /*  53 */
    parse_null,     /*  54 */
    parse_null,     /*  55 */
    parse_null,     /*  56 */
    parse_null,     /*  57 */
    parse_null,     /*  58 */
    parse_null,     /*  59 */
    parse_null,     /*  60 */
    parse_null,     /*  61 */
    parse_null,     /*  62 */
    parse_process,  /*  63 */
    parse_null,     /*  64 */
    parse_start,    /*  65 */
    parse_start,    /*  66 */
    parse_start,    /*  67 */
    parse_start,    /*  68 */
    parse_start,    /*  69 */
    parse_start,    /*  70 */
    parse_start,    /*  71 */
    parse_start,    /*  72 */
    parse_start,    /*  73 */
    parse_start,    /*  74 */
    parse_start,    /*  75 */
    parse_start,    /*  76 */
    parse_start,    /*  77 */
    parse_start,    /*  78 */
    parse_start,    /*  79 */
    parse_start,    /*  80 */
    parse_start,    /*  81 */
    parse_start,    /*  82 */
    parse_start,    /*  83 */
    parse_start,    /*  84 */
    parse_start,    /*  85 */
    parse_start,    /*  86 */
    parse_start,    /*  87 */
    parse_start,    /*  88 */
    parse_start,    /*  89 */
    parse_start,    /*  90 */
    parse_null,     /*  91 */
    parse_null,     /*  92 */
    parse_null,     /*  93 */
    parse_null,     /*  94 */
    parse_null,     /*  95 */
    parse_null,     /*  96 */
    parse_start,    /*  97 */
    parse_start,    /*  98 */
    parse_start,    /*  99 */
    parse_start,    /* 100 */
    parse_start,    /* 101 */
    parse_start,    /* 102 */
    parse_start,    /* 103 */
    parse_start,    /* 104 */
    parse_start,    /* 105 */
    parse_start,    /* 106 */
    parse_start,    /* 107 */
    parse_start,    /* 108 */
    parse_start,    /* 109 */
    parse_start,    /* 110 */
    parse_start,    /* 111 */
    parse_start,    /* 112 */
    parse_start,    /* 113 */
    parse_start,    /* 114 */
    parse_start,    /* 115 */
    parse_start,    /* 116 */
    parse_start,    /* 117 */
    parse_start,    /* 118 */
    parse_start,    /* 119 */
    parse_start,    /* 120 */
    parse_start,    /* 121 */
    parse_start,    /* 122 */
    parse_null,     /* 123 */
    parse_null,     /* 124 */
    parse_null,     /* 125 */
    parse_null,     /* 126 */
    parse_null,     /* 127 */
    parse_null,     /* 128 */
    parse_null,     /* 129 */
    parse_null,     /* 130 */
    parse_null,     /* 131 */
    parse_null,     /* 132 */
    parse_null,     /* 133 */
    parse_null,     /* 134 */
    parse_null,     /* 135 */
    parse_null,     /* 136 */
    parse_null,     /* 137 */
    parse_null,     /* 138 */
    parse_null,     /* 139 */
    parse_null,     /* 140 */
    parse_null,     /* 141 */
    parse_null,     /* 142 */
    parse_null,     /* 143 */
    parse_null,     /* 144 */
    parse_null,     /* 145 */
    parse_null,     /* 146 */
    parse_null,     /* 147 */
    parse_null,     /* 148 */
    parse_null,     /* 149 */
    parse_null,     /* 150 */
    parse_null,     /* 151 */
    parse_null,     /* 152 */
    parse_null,     /* 153 */
    parse_null,     /* 154 */
    parse_null,     /* 155 */
    parse_null,     /* 156 */
    parse_null,     /* 157 */
    parse_null,     /* 158 */
    parse_null,     /* 159 */
    parse_null,     /* 160 */
    parse_null,     /* 161 */
    parse_null,     /* 162 */
    parse_null,     /* 163 */
    parse_null,     /* 164 */
    parse_null,     /* 165 */
    parse_null,     /* 166 */
    parse_null,     /* 167 */
    parse_null,     /* 168 */
    parse_null,     /* 169 */
    parse_null,     /* 170 */
    parse_null,     /* 171 */
    parse_null,     /* 172 */
    parse_null,     /* 173 */
    parse_null,     /* 174 */
    parse_null,     /* 175 */
    parse_null,     /* 176 */
    parse_null,     /* 177 */
    parse_null,     /* 178 */
    parse_null,     /* 179 */
    parse_null,     /* 180 */
    parse_null,     /* 181 */
    parse_null,     /* 182 */
    parse_null,     /* 183 */
    parse_null,     /* 184 */
    parse_null,     /* 185 */
    parse_null,     /* 186 */
    parse_null,     /* 187 */
    parse_null,     /* 188 */
    parse_null,     /* 189 */
    parse_null,     /* 190 */
    parse_null,     /* 191 */
    parse_null,     /* 192 */
    parse_null,     /* 193 */
    parse_null,     /* 194 */
    parse_null,     /* 195 */
    parse_null,     /* 196 */
    parse_null,     /* 197 */
    parse_null,     /* 198 */
    parse_null,     /* 199 */
    parse_null,     /* 200 */
    parse_null,     /* 201 */
    parse_null,     /* 202 */
    parse_null,     /* 203 */
    parse_null,     /* 204 */
    parse_null,     /* 205 */
    parse_null,     /* 206 */
    parse_null,     /* 207 */
    parse_null,     /* 208 */
    parse_null,     /* 209 */
    parse_null,     /* 210 */
    parse_null,     /* 211 */
    parse_null,     /* 212 */
    parse_null,     /* 213 */
    parse_null,     /* 214 */
    parse_null,     /* 215 */
    parse_null,     /* 216 */
    parse_null,     /* 217 */
    parse_null,     /* 218 */
    parse_null,     /* 219 */
    parse_null,     /* 220 */
    parse_null,     /* 221 */
    parse_null,     /* 222 */
    parse_null,     /* 223 */
    parse_null,     /* 224 */
    parse_null,     /* 225 */
    parse_null,     /* 226 */
    parse_null,     /* 227 */
    parse_null,     /* 228 */
    parse_null,     /* 229 */
    parse_null,     /* 230 */
    parse_null,     /* 231 */
    parse_null,     /* 232 */
    parse_null,     /* 233 */
    parse_null,     /* 234 */
    parse_null,     /* 235 */
    parse_null,     /* 236 */
    parse_null,     /* 237 */
    parse_null,     /* 238 */
    parse_null,     /* 239 */
    parse_null,     /* 240 */
    parse_null,     /* 241 */
    parse_null,     /* 242 */
    parse_null,     /* 243 */
    parse_null,     /* 244 */
    parse_null,     /* 245 */
    parse_null,     /* 246 */
    parse_null,     /* 247 */
    parse_null,     /* 248 */
    parse_null,     /* 249 */
    parse_null,     /* 250 */
    parse_null,     /* 251 */
    parse_null,     /* 252 */
    parse_null,     /* 253 */
    parse_null,     /* 254 */
    parse_null,     /* 255 */
};
