use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;

set_spell_cmd('aspell list');
add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
49699333
883514
Aas
Alders
Antonio
Attr
Attrseq
Barbie
Bonaccorso
CDATA
CPAN
Chase
Chip
Clark
Damyan
David
Dtext
Entities
Filter
François
Germishuys
Gisle
Graham
HTML
HeadParser
IMG
Isindex
Ivanov
Jacques
James
Jensen
Jess
Jon
Josef
Knop
LinkExtor
Lukas
MSIE
Mai
Michael
Michal
Mike
Nicholas
Nicolas
Olaf
Orton
Parser
Perrad
PullParser
Radici
Raspass
Rinaldo
Robinson
Salvatore
Salzenberg
Skyttä
South
Steinbrunner
Textification
Todd
TokeParser
Tokenpos
Unterminated
Ville
Whitener
Yves
Zefram
and
antonio
argspec
argspecs
barbie
bulk88
capoeirab
castaway
chip
demerphq
dependabot
dmn
dsteinbrunner
francois
gaas
gisle
haarg
jacquesg
jon
jraspass
lib
lukasmai
mchase
msouth
mspacek
nick
nicolas
olaf
salvatore
tagname
textified
toddr
undecoded
ville
yoshikazusawa
zefram
Špaček
